@@ -19,6 +19,9 @@ class YowConstants:
         ("e16.whatsapp.net", 443),
         )
 
+    WHATSAPP_SERVER = "s.whatsapp.net"
+    WHATSAPP_GROUP_SERVER = "g.us"
+
     PATH_STORAGE = "~/.yowsup"
 
     PREVIEW_WIDTH = 64
