@@ -2,7 +2,7 @@ from yowsup.stacks import  YowStackBuilder
 from .layer import YowsupCliLayer
 from yowsup.layers.auth import AuthError
 from yowsup.layers import YowLayerEvent
-from yowsup.layers.auth import YowAuthenticationProtocolLayer
+from yowsup.layers.axolotl.props import PROP_IDENTITY_AUTOTRUST
 import sys
 
 class YowsupCliStack(object):
@@ -16,6 +16,7 @@ class YowsupCliStack(object):
 
         # self.stack.setCredentials(credentials)
         self.stack.setCredentials(credentials)
+        self.stack.setProp(PROP_IDENTITY_AUTOTRUST, True)
 
     def start(self):
         print("Yowsup Cli client\n==================\nType /help for available commands\n")
