@@ -1,4 +1,3 @@
+from .env import YowsupEnv
 from .env_android import AndroidYowsupEnv
 from .env_s40 import S40YowsupEnv
-
-CURRENT_ENV = S40YowsupEnv()
