@@ -1,13 +1,12 @@
 from .env import YowsupEnv
-import base64
 import hashlib
 class S40YowsupEnv(YowsupEnv):
-    _VERSION = "2.13.39"
+    _VERSION = "2.16.12"
     _OS_NAME= "S40"
     _OS_VERSION = "14.26"
     _DEVICE_NAME = "302"
     _MANUFACTURER = "Nokia"
-    _TOKEN_STRING  = "PdA2DJyKoUrwLw1Bg6EIhzh502dF9noR9uFCllGk1456529096701{phone}"
+    _TOKEN_STRING  = "PdA2DJyKoUrwLw1Bg6EIhzh502dF9noR9uFCllGk1494451854337{phone}"
     _AXOLOTL = True
 
     def getVersion(self):
@@ -22,6 +21,9 @@ class S40YowsupEnv(YowsupEnv):
     def getDeviceName(self):
         return self.__class__._DEVICE_NAME
 
+    def getManufacturer(self):
+        return self.__class__._MANUFACTURER
+
     def isAxolotlEnabled(self):
         return self.__class__._AXOLOTL
 
@@ -33,5 +35,6 @@ class S40YowsupEnv(YowsupEnv):
             WHATSAPP_VERSION = self.getVersion(),
             OS_NAME = self.getOSName() + "Version",
             OS_VERSION = self.getOSVersion(),
-            DEVICE_NAME = self.getDeviceName()
+            DEVICE_NAME = self.getDeviceName(),
+            MANUFACTURER = self.getManufacturer()
         )
