@@ -1,8 +1,9 @@
 from yowsup.layers.auth.protocolentities.response import ResponseProtocolEntity
 from yowsup.structs import ProtocolTreeNode
 from yowsup.structs.protocolentity import ProtocolEntityTest
+import unittest
 
-class ResponseProtocolEntityTest(ProtocolEntityTest):
+class ResponseProtocolEntityTest(ProtocolEntityTest, unittest.TestCase):
     def setUp(self):
         self.ProtocolEntity = ResponseProtocolEntity
         attribs = {
