@@ -2,4 +2,7 @@ from .iq_key_get import GetKeysIqProtocolEntity
 from .iq_keys_set import SetKeysIqProtocolEntity
 from .iq_keys_get_result import ResultGetKeysIqProtocolEntity
 from .message_encrypted import EncryptedMessageProtocolEntity
-from .notification_encrypt import EncryptNotification
\ No newline at end of file
+from .enc import EncProtocolEntity
+from .notification_encrypt import EncryptNotification
+from .receipt_outgoing_retry import RetryOutgoingReceiptProtocolEntity
+from .receipt_incoming_retry import RetryIncomingReceiptProtocolEntity
