@@ -3,6 +3,7 @@ from .liteidentitykeystore import LiteIdentityKeyStore
 from .liteprekeystore import LitePreKeyStore
 from .litesessionstore import LiteSessionStore
 from .litesignedprekeystore import LiteSignedPreKeyStore
+from .litesenderkeystore import LiteSenderKeyStore
 import sqlite3
 class LiteAxolotlStore(AxolotlStore):
     def __init__(self, db):
@@ -12,6 +13,7 @@ class LiteAxolotlStore(AxolotlStore):
         self.preKeyStore =  LitePreKeyStore(conn)
         self.signedPreKeyStore = LiteSignedPreKeyStore(conn)
         self.sessionStore = LiteSessionStore(conn)
+        self.senderKeyStore = LiteSenderKeyStore(conn)
 
     def getIdentityKeyPair(self):
         return self.identityKeyStore.getIdentityKeyPair()
@@ -74,4 +76,10 @@ class LiteAxolotlStore(AxolotlStore):
         return self.signedPreKeyStore.containsSignedPreKey(signedPreKeyId)
 
     def removeSignedPreKey(self, signedPreKeyId):
-        self.signedPreKeyStore.removeSignedPreKey(signedPreKeyId)
\ No newline at end of file
+        self.signedPreKeyStore.removeSignedPreKey(signedPreKeyId)
+
+    def loadSenderKey(self, senderKeyName):
+        return self.senderKeyStore.loadSenderKey(senderKeyName)
+
+    def storeSenderKey(self, senderKeyName, senderKeyRecord):
+        self.senderKeyStore.storeSenderKey(senderKeyName, senderKeyRecord)
