@@ -1,6 +1,7 @@
 from axolotl.state.signedprekeystore import SignedPreKeyStore
 from axolotl.state.signedprekeyrecord import SignedPreKeyRecord
 from axolotl.invalidkeyidexception import InvalidKeyIdException
+import sys
 class LiteSignedPreKeyStore(SignedPreKeyStore):
     def __init__(self, dbConn):
         """
@@ -42,7 +43,8 @@ class LiteSignedPreKeyStore(SignedPreKeyStore):
 
         q = "INSERT INTO signed_prekeys (prekey_id, record) VALUES(?,?)"
         cursor = self.dbConn.cursor()
-        cursor.execute(q, (signedPreKeyId, signedPreKeyRecord.serialize()))
+        record = signedPreKeyRecord.serialize()
+        cursor.execute(q, (signedPreKeyId, buffer(record) if sys.version_info < (2,7) else record))
         self.dbConn.commit()
 
     def containsSignedPreKey(self, signedPreKeyId):
