@@ -1,4 +1,4 @@
-from yowsup.layers import YowLayer, YowLayerEvent
+from yowsup.layers import YowLayer, YowLayerEvent, EventCallback
 from yowsup.layers.network import YowNetworkLayer
 from .encoder import WriteEncoder
 from .decoder import ReadDecoder
@@ -13,18 +13,18 @@ class YowCoderLayer(YowLayer):
         tokenDictionary = TokenDictionary()
         self.writer = WriteEncoder(tokenDictionary)
         self.reader = ReadDecoder(tokenDictionary)
-
-    def onEvent(self, event):
-        if event.getName() == YowNetworkLayer.EVENT_STATE_CONNECTED:
-            self.writer.reset()
-            self.reader.reset()
-            streamStartBytes = self.writer.getStreamStartBytes(
-                self.getProp(self.__class__.PROP_DOMAIN),
-                self.getProp(self.__class__.PROP_RESOURCE)
-            )
-            for i in range(0, 4):
-                self.write(streamStartBytes.pop(0))
-            self.write(streamStartBytes)
+    
+    @EventCallback(YowNetworkLayer.EVENT_STATE_CONNECTED)
+    def onConnected(self, event):
+        self.writer.reset()
+        self.reader.reset()
+        streamStartBytes = self.writer.getStreamStartBytes(
+            self.getProp(self.__class__.PROP_DOMAIN),
+            self.getProp(self.__class__.PROP_RESOURCE)
+        )
+        for i in range(0, 4):
+            self.write(streamStartBytes.pop(0))
+        self.write(streamStartBytes)        
 
     def send(self, data):
         self.write(self.writer.protocolTreeNodeToBytes(data))
