@@ -18,8 +18,14 @@ class YowNetworkLayer(YowLayer, asyncore.dispatcher_with_send):
     PROP_ENDPOINT               = "org.openwhatsapp.yowsup.prop.endpoint"
     PROP_NET_READSIZE           = "org.openwhatsapp.yowsup.prop.net.readSize"
 
+    STATE_DISCONNECTED          = 0
+    STATE_CONNECTING            = 1
+    STATE_CONNECTED             = 2
+    STATE_DISCONNECTING         = 3
+
     def __init__(self):
         asyncore.dispatcher.__init__(self)
+        self.state = self.__class__.STATE_DISCONNECTED
         YowLayer.__init__(self)
         self.interface = YowNetworkLayerInterface(self)
         httpProxy = HttpProxy.getFromEnviron()
@@ -33,18 +39,19 @@ class YowNetworkLayer(YowLayer, asyncore.dispatcher_with_send):
             proxyHandler = httpProxy.handler()
             proxyHandler.onConnect = onConnect
         self.proxyHandler = proxyHandler
-        
+
     @EventCallback(EVENT_STATE_CONNECT)
     def onConnect(self, ev):
         self.createConnection()
         return True
-    
+
     @EventCallback(EVENT_STATE_DISCONNECT)
     def onDisconnect(self, ev):
         self.destroyConnection(ev.getArg("reason"))
-        return True        
+        return True
 
     def createConnection(self):
+        self.state = self.__class__.STATE_CONNECTING
         self.create_socket(socket.AF_INET, socket.SOCK_STREAM)
         self.out_buffer = bytearray()
         endpoint = self.getProp(self.__class__.PROP_ENDPOINT)
@@ -53,15 +60,20 @@ class YowNetworkLayer(YowLayer, asyncore.dispatcher_with_send):
             logger.debug("HttpProxy connect: %s:%d" % endpoint)
             self.proxyHandler.connect(self, endpoint)
         else:
-            self.connect(endpoint)
+            try:
+                self.connect(endpoint)
+            except OSError as e:
+                self.handle_close(e)
 
     def destroyConnection(self, reason = None):
+        self.state = self.__class__.STATE_DISCONNECTING
         self.handle_close(reason or "Requested")
 
     def getStatus(self):
         return self.connected
 
     def handle_connect(self):
+        self.state = self.__class__.STATE_CONNECTED
         self.connected = True
         if self.proxyHandler != None:
             logger.debug("HttpProxy handle connect")
@@ -70,10 +82,12 @@ class YowNetworkLayer(YowLayer, asyncore.dispatcher_with_send):
             self.emitEvent(YowLayerEvent(YowNetworkLayer.EVENT_STATE_CONNECTED))
 
     def handle_close(self, reason = "Connection Closed"):
-        self.connected = False
-        logger.debug("Disconnected, reason: %s" % reason)
-        self.emitEvent(YowLayerEvent(self.__class__.EVENT_STATE_DISCONNECTED, reason = reason, detached=True))
-        self.close()
+        if self.state != self.__class__.STATE_DISCONNECTED:
+            self.state = self.__class__.STATE_DISCONNECTED
+            self.connected = False
+            logger.debug("Disconnected, reason: %s" % reason)
+            self.emitEvent(YowLayerEvent(self.__class__.EVENT_STATE_DISCONNECTED, reason = reason, detached=True))
+            self.close()
 
     def handle_error(self):
         raise
