@@ -1,3 +1,4 @@
+from yowsup.common import YowConstants
 from yowsup.structs import ProtocolTreeNode
 from yowsup.layers.protocol_iq.protocolentities import ResultIqProtocolEntity
 class SuccessCreateGroupsIqProtocolEntity(ResultIqProtocolEntity):
@@ -8,7 +9,7 @@ class SuccessCreateGroupsIqProtocolEntity(ResultIqProtocolEntity):
     '''
 
     def __init__(self, _id, groupId):
-        super(SuccessCreateGroupsIqProtocolEntity, self).__init__(_from = "g.us", _id = _id)
+        super(SuccessCreateGroupsIqProtocolEntity, self).__init__(_from = YowConstants.WHATSAPP_GROUP_SERVER, _id = _id)
         self.setProps(groupId)
 
     def setProps(self, groupId):
