@@ -1,8 +1,9 @@
 from yowsup.layers.protocol_iq.protocolentities.iq import IqProtocolEntity
 from yowsup.structs import ProtocolTreeNode
 from yowsup.structs.protocolentity import ProtocolEntityTest
+import unittest
 
-class IqProtocolEntityTest(ProtocolEntityTest):
+class IqProtocolEntityTest(unittest.TestCase, ProtocolEntityTest):
     def setUp(self):
         self.ProtocolEntity = IqProtocolEntity
         self.node = ProtocolTreeNode("iq", {"id": "test_id", "type": "get", "xmlns": "iq_xmlns"}, None, None)
\ No newline at end of file
