@@ -1,6 +1,8 @@
 from .message_media import MediaMessageProtocolEntity
 from .message_media_downloadable import DownloadableMediaMessageProtocolEntity
 from .message_media_downloadable_image import ImageDownloadableMediaMessageProtocolEntity
+from .message_media_downloadable_audio import AudioDownloadableMediaMessageProtocolEntity
+from .message_media_downloadable_video import VideoDownloadableMediaMessageProtocolEntity
 from .message_media_location import LocationMediaMessageProtocolEntity
 from .message_media_vcard import VCardMediaMessageProtocolEntity
 from .iq_requestupload import RequestUploadIqProtocolEntity
