@@ -4,32 +4,32 @@ from yowsup.common.tools import MimeTools
 import os
 class DownloadableMediaMessageProtocolEntity(MediaMessageProtocolEntity):
     '''
-    <message t="{{TIME_STAMP}}" from="{{CONTACT_JID}}" 
+    <message t="{{TIME_STAMP}}" from="{{CONTACT_JID}}"
         offline="{{OFFLINE}}" type="text" id="{{MESSAGE_ID}}" notify="{{NOTIFY_NAME}}">
         <media type="{{DOWNLOADABLE_MEDIA_TYPE: (image | audio | video)}}"
-            mimetype="{{MIME_TYPE}}" 
+            mimetype="{{MIME_TYPE}}"
             filehash="{{FILE_HASH}}"
-            url="{{DOWNLOAD_URL}}" 
+            url="{{DOWNLOAD_URL}}"
             ip="{{IP}}"
             size="{{MEDIA SIZE}}"
-            file="{{FILENAME}}" 
+            file="{{FILENAME}}"
 
             > {{THUMBNAIL_RAWDATA (JPEG?)}}
         </media>
     </message>
     '''
     def __init__(self, mediaType,
-            mimeType, fileHash, url, ip, size, fileName, 
-            _id = None, _from = None, to = None, notify = None, timestamp = None, 
+            mimeType, fileHash, url, ip, size, fileName, mediaKey = None,
+            _id = None, _from = None, to = None, notify = None, timestamp = None,
             participant = None, preview = None, offline = None, retry = None):
 
         super(DownloadableMediaMessageProtocolEntity, self).__init__(mediaType, _id, _from, to, notify, timestamp, participant, preview, offline, retry)
-        self.setDownloadableMediaProps(mimeType, fileHash, url, ip, size, fileName)
+        self.setDownloadableMediaProps(mimeType, fileHash, url, ip, size, fileName, mediaKey)
 
     def __str__(self):
         out  = super(DownloadableMediaMessageProtocolEntity, self).__str__()
         out += "MimeType: %s\n" % self.mimeType
-        out += "File Hash: %s\n" % self.fileHash
+        out += "File Hash: %s\n" % self.fileHash.encode('hex')
         out += "URL: %s\n" % self.url
         out += "IP: %s\n" % self.ip
         out += "File Size: %s\n" % self.size
@@ -45,13 +45,14 @@ class DownloadableMediaMessageProtocolEntity(MediaMessageProtocolEntity):
     def getMimeType(self):
         return self.mimeType
 
-    def setDownloadableMediaProps(self, mimeType, fileHash, url, ip, size, fileName):
+    def setDownloadableMediaProps(self, mimeType, fileHash, url, ip, size, fileName, mediaKey):
         self.mimeType   = mimeType
         self.fileHash   = fileHash
         self.url        = url
         self.ip         = ip
         self.size       = int(size)
         self.fileName   = fileName
+        self.mediaKey   = mediaKey
 
     def toProtocolTreeNode(self):
         node = super(DownloadableMediaMessageProtocolEntity, self).toProtocolTreeNode()
@@ -63,9 +64,14 @@ class DownloadableMediaMessageProtocolEntity(MediaMessageProtocolEntity):
             mediaNode.setAttribute("ip",        self.ip)
         mediaNode.setAttribute("size",      str(self.size))
         mediaNode.setAttribute("file",      self.fileName)
+        if self.mediaKey:
+            mediaNode.setAttribute("mediakey", self.mediaKey)
 
         return node
 
+    def isEncrypted(self):
+        return self.mediaKey is not None
+
     @staticmethod
     def fromProtocolTreeNode(node):
         entity = MediaMessageProtocolEntity.fromProtocolTreeNode(node)
@@ -77,17 +83,18 @@ class DownloadableMediaMessageProtocolEntity(MediaMessageProtocolEntity):
             mediaNode.getAttributeValue("url"),
             mediaNode.getAttributeValue("ip"),
             mediaNode.getAttributeValue("size"),
-            mediaNode.getAttributeValue("file")
+            mediaNode.getAttributeValue("file"),
+            mediaNode.getAttributeValue("mediakey")
             )
         return entity
 
     @staticmethod
-    def fromFilePath(fpath, url, mediaType, ip, to, mimeType = None, preview = None, filehash = None, filesize = None):
-        mimeType = mimeType or MimeTools.getMIME(fpath)
-        filehash = filehash or WATools.getFileHashForUpload(fpath)
-        size = filesize or os.path.getsize(fpath)
-        fileName = os.path.basename(fpath)
-
-        return DownloadableMediaMessageProtocolEntity(mediaType, mimeType, filehash, url, ip, size, fileName, to = to, preview = preview)
-
-
+    def fromBuilder(builder):
+        url = builder.get("url")
+        ip = builder.get("ip")
+        assert url, "Url is required"
+        mimeType = builder.get("mimetype", MimeTools.getMIME(builder.getOriginalFilepath())[0])
+        filehash = WATools.getFileHashForUpload(builder.getFilepath())
+        size = os.path.getsize(builder.getFilepath())
+        fileName = os.path.basename(builder.getFilepath())
+        return DownloadableMediaMessageProtocolEntity(builder.mediaType, mimeType, filehash, url, ip, size, fileName, to = builder.jid, preview = builder.get("preview"))
