@@ -3,3 +3,5 @@ from .presence_available    import AvailablePresenceProtocolEntity
 from .presence_unavailable  import UnavailablePresenceProtocolEntity
 from .presence_subscribe    import SubscribePresenceProtocolEntity
 from .presence_unsubscribe  import UnsubscribePresenceProtocolEntity
+from .iq_lastseen           import LastseenIqProtocolEntity
+from .iq_lastseen_result    import ResultLastseenIqProtocolEntity
