@@ -46,6 +46,7 @@ class YowStackBuilder(object):
 
     def setProp(self, key, value):
         self._props[key] = value
+        return self
 
     def pushDefaultLayers(self, axolotl = False):
         defaultLayers = YowStackBuilder.getDefaultLayers(axolotl)
@@ -70,8 +71,9 @@ class YowStackBuilder(object):
 
         allLayers = coreLayers
         if axolotl:
-            from yowsup.layers.axolotl import YowAxolotlLayer
-            allLayers += (YowAxolotlLayer,)
+            from yowsup.layers.axolotl import AxolotlSendLayer, AxolotlControlLayer, AxolotlReceivelayer
+            allLayers += (AxolotlControlLayer,)
+            allLayers += (YowParallelLayer((AxolotlSendLayer, AxolotlReceivelayer)),)
 
         allLayers += (YowParallelLayer(protocolLayers),)
 
